@@ -4,6 +4,7 @@ declare(strict_types=1);
 
 namespace Ramsey\Uuid\Test;
 
+use BadMethodCallException;
 use Brick\Math\BigDecimal;
 use Brick\Math\RoundingMode;
 use DateTimeImmutable;
@@ -40,6 +41,7 @@ use Ramsey\Uuid\UuidFactoryInterface;
 use Ramsey\Uuid\UuidInterface;
 use Ramsey\Uuid\Validator\GenericValidator;
 use Ramsey\Uuid\Validator\ValidatorInterface;
+use Stringable;
 use stdClass;
 
 use function base64_decode;
@@ -73,6 +75,37 @@ class UuidTest extends TestCase
         );
     }
 
+    public function testFromHexadecimal(): void
+    {
+        $hex = new Hexadecimal('0x1EA78DEB37CE625E8F1A025041000001');
+        $uuid = Uuid::fromHexadecimal($hex);
+        $this->assertInstanceOf(Uuid::class, $uuid);
+        $this->assertEquals('1ea78deb-37ce-625e-8f1a-025041000001', $uuid->toString());
+    }
+
+    public function testFromHexadecimalShort(): void
+    {
+        $hex = new Hexadecimal('0x1EA78DEB37CE625E8F1A0250410000');
+
+        $this->expectException(InvalidUuidStringException::class);
+        $this->expectExceptionMessage('Invalid UUID string:');
+
+        Uuid::fromHexadecimal($hex);
+    }
+
+    public function testFromHexadecimalThrowsWhenMethodDoesNotExist(): void
+    {
+        $factory = Mockery::mock(UuidFactoryInterface::class);
+        Uuid::setFactory($factory);
+
+        $hex = new Hexadecimal('0x1EA78DEB37CE625E8F1A025041000001');
+
+        $this->expectException(BadMethodCallException::class);
+        $this->expectExceptionMessage('The method fromHexadecimal() does not exist on the provided factory');
+
+        Uuid::fromHexadecimal($hex);
+    }
+
     /**
      * Tests that UUID and GUID's have the same textual representation but not
      * the same binary representation.
@@ -543,11 +576,19 @@ class UuidTest extends TestCase
         $uuid = Uuid::fromString('ff6f8cb0-c57d-11e1-9b21-0800200c9a66');
         $this->assertSame('ff6f8cb0-c57d-11e1-9b21-0800200c9a66', $uuid->toString());
         $this->assertSame('ff6f8cb0-c57d-11e1-9b21-0800200c9a66', (string) $uuid);
+        $this->assertSame(
+            'ff6f8cb0-c57d-11e1-9b21-0800200c9a66',
+            (static fn (Stringable $uuid) => (string) $uuid)($uuid)
+        );
 
         // Check with an old date
         $uuid = Uuid::fromString('0901e600-0154-1000-9b21-0800200c9a66');
         $this->assertSame('0901e600-0154-1000-9b21-0800200c9a66', $uuid->toString());
         $this->assertSame('0901e600-0154-1000-9b21-0800200c9a66', (string) $uuid);
+        $this->assertSame(
+            '0901e600-0154-1000-9b21-0800200c9a66',
+            (static fn (Stringable $uuid) => (string) $uuid)($uuid)
+        );
     }
 
     public function testUuid1(): void
